@@ -1,10 +1,10 @@
 `hglm.formula` <-
 	function(X = NULL, y = NULL, Z = NULL, family = gaussian(link = identity),
-             rand.family = gaussian(link = identity), method = "EQL", conv = 1e-6, maxit = 50, startval = NULL,
-             fixed = NULL, random = NULL, X.disp = NULL, disp = NULL,
-             link.disp = "log", data = NULL, weights = NULL, fix.disp = NULL, offset = NULL, 
-             RandC = NULL, sparse = TRUE, vcovmat = FALSE, calc.like = FALSE, 
-			 bigRR = FALSE, verbose = FALSE, ...) {
+			rand.family = gaussian(link = identity), method = "EQL", conv = 1e-6, maxit = 50, 
+			startval = NULL, fixed = NULL, random = NULL, X.disp = NULL, disp = NULL, 
+			link.disp = "log", X.rand.disp = NULL, rand.disp = NULL, link.rand.disp = "log", 
+			data = NULL, weights = NULL, fix.disp = NULL, offset = NULL, RandC = ncol(Z), 
+			sparse = TRUE, vcovmat = FALSE, calc.like = FALSE, bigRR = FALSE, verbose = FALSE, ...) {
 
 Call <- match.call()
 
